@@ -15,11 +15,10 @@ sub init
     $Petal::ENCODE_CHARSET = 'utf8';
     $Petal::BASE_DIR = undef;
 
-    @Petal::BASE_DIR = map { (-e $_ and -d $_) ? $_ : () } (
+    @Petal::BASE_DIR = map { -d $_ ? $_ : () } (
         $ENV{SITE_DIR}  . '/resources/templates',
         $ENV{MKDOC_DIR} . '/resources/templates',
-        (map { "$_/MKDoc/templates" } @INC),
-        (map { "$_/templates" } @INC)
+        (map { "$_/MKDoc/resources/templates" } @INC ),
     );
 }
 
